@@ -188,7 +188,11 @@ def clone_github_repo(github_url,datadir, destfolder):
     validate_path(datadir,destfolder)
     logFileName = os.path.join(data_dir, '{}_upload_log.txt'.format(destfolder))
     destfolder = os.path.join(data_dir, destfolder)
-    cmd = 'git clone {} {}'.format(github_url,destfolder)
-    proc = evaluate_cmd(cmd, logFileName)
-    proc.kill()
+    if os.path.exists(destfolder):
+        print("Git Clone Destination folder already exists")
+    else:
+        print("Cloning")
+        cmd = 'git clone {} {}'.format(github_url,destfolder)
+        proc = evaluate_cmd(cmd, logFileName)
+        proc.kill()
 
